pub enum OverflowMode {
Panic,
UB,
Wrap,
}Variants
Panic
If this operation overflows, it panics. Only exists in debug mode, for instance in
a + b, and only if --reconstruct-fallible-operations is passed to Charon. Otherwise the
bound check will be explicit.
UB
If this operation overflows, it is UB; for instance in core::num::unchecked_add. This can
exists in safe code, but will always be preceded by a bounds check.
Wrap
If this operation overflows, it wraps around for instance in core::num::wrapping_add,
or a + b in release mode.